package com.mgh.pmdm.parques.db

import android.content.Context
import androidx.room.Database
import androidx.room.Room
import androidx.room.RoomDatabase

// con la anotación @Database definimos una lista
// con las entidades con las que trabaja nuestra BD
// y su versión.
@Database(entities = [Park::class], version = 1)
abstract class ParksDB : RoomDatabase() {
    // Métodos que devuelven los DAO que hemos implementado
    // Y con los cuales accederemos a la BD
    abstract fun parkDao(): ParkDAO
}

// Implementación del patrón Singleton
object DatabaseBuilder {

    private var INSTANCE: ParksDB? = null

    fun getInstance(context: Context): ParksDB {
        if (INSTANCE == null) {
            synchronized(ParksDB::class) {
                INSTANCE = buildRoomDB(context)
            }
        }
        return INSTANCE!!
    }

    // Constructor privado
    private fun buildRoomDB(contexto: Context) =
        Room.databaseBuilder(
            contexto.applicationContext,
            ParksDB::class.java,
            "parks-db"
        ).build()

}
